class Detakon():
    """detakon uses a mapping file to convert data in one file type to another."""
    def __init__(self, detamap, source, destination, stype: str="csv", dtype: str="csv", *args, **kargs):
        """
        Docstring for __init__
        
        :param self: self object.
        :param detamap: detamap file location that describes field mappings, default values, and operations to perform on data.
        :param source: Source file to input.
        :param destination: Destination file to output.
        :param stype: Source file type. Defaults to CSV.
        :type stype: str
        :param dtype: Destination file type. Defaults to CSV.
        :type dtype: str
        :param args: Additional parameters.
        :param kargs: Addtional flags.
        """
        pass